@@ -139,6 +139,8 @@ def test_fn_pointer_params() -> None:
       int fn1(int *);
       int fn2(int *p);
       int fn3(int(*p));
+      int fn4(int* __restrict__ p);
+      int fn5(int& __restrict__ p);
     """
     data = parse_string(content, cleandoc=True)
 
@@ -198,6 +200,44 @@ def test_fn_pointer_params() -> None:
                         )
                     ],
                 ),
+                Function(
+                    return_type=Type(
+                        typename=PQName(segments=[FundamentalSpecifier(name="int")])
+                    ),
+                    name=PQName(segments=[NameSpecifier(name="fn4")]),
+                    parameters=[
+                        Parameter(
+                            name="p",
+                            type=Pointer(
+                                ptr_to=Type(
+                                    typename=PQName(
+                                        segments=[FundamentalSpecifier(name="int")]
+                                    )
+                                ),
+                                restrict=True,
+                            ),
+                        )
+                    ],
+                ),
+                Function(
+                    return_type=Type(
+                        typename=PQName(segments=[FundamentalSpecifier(name="int")])
+                    ),
+                    name=PQName(segments=[NameSpecifier(name="fn5")]),
+                    parameters=[
+                        Parameter(
+                            name="p",
+                            type=Reference(
+                                ref_to=Type(
+                                    typename=PQName(
+                                        segments=[FundamentalSpecifier(name="int")]
+                                    )
+                                ),
+                                restrict=True,
+                            ),
+                        )
+                    ],
+                ),
             ]
         )
     )
